==> 0.0.7.tar.gz: lib/src/screens/verifyemail.dart <==
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:loading_overlay/loading_overlay.dart';
import 'package:otp_text_field/otp_field.dart';
import 'package:otp_text_field/style.dart';
import 'package:storebounty_auth/src/widget/alert/alertclass.dart';
import 'package:storebounty_auth/src/widget/custombutton.dart';
import 'package:storebounty_auth/src/widget/styles/colors.dart';
import 'package:storebounty_auth/src/widget/styles/textstles.dart';
import 'package:storebounty_auth/storebounty_auth_v1.dart';
import 'package:storebounty_init/storebountyinit.dart';

class VerifyEmail extends StatefulWidget {
  static const pageId = "verify-email-otp-screen";
  final VoidCallback emailVerified;
  const VerifyEmail({super.key, required this.emailVerified});

  @override
  State<VerifyEmail> createState() => _VerifyEmailState();
}

class _VerifyEmailState extends State<VerifyEmail> {
  TextEditingController otpResetPasswordVerifyCtx = TextEditingController();

  Color? defaultColor;
  bool isVerifyingEmail = false;

  @override
  void initState() {
    getColor();
    // resetDiscountCode();
    super.initState();
  }

  getColor() async {
    var colorString = await StoreBountyInit.getStoreColor() ?? "#000000";
    defaultColor = Color(int.parse("0xff" + colorString.substring(1)));
    var currencySymbol = await StoreBountyInit.getCurrencySymbol();
    setState(() {});
  }

  resetPasswordStart()async{

    try{

      setState(() {
        isVerifyingEmail = true;
      });

      var body = {
        "otp": otpResetPasswordVerifyCtx.text.trim()
      };

      final response = await StorebountyAuth.sendResetPasswordOtp(body);

     widget.emailVerified();

    }catch(e){
      AlertClass.error(context, "$e");
      setState(() {
        isVerifyingEmail = false;
      });

    }

  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () {
        FocusScope.of(context).unfocus();
      },
      child: LoadingOverlay(
        isLoading: isVerifyingEmail,
        color: defaultColor?.withOpacity(0.2) ?? Color(0xff0000).withOpacity(0.2),
        progressIndicator: CircularProgressIndicator(
          color: defaultColor,
        ),
        child: Scaffold(
          backgroundColor: AppColors.whiteColor,
          body: Container(
            child: SingleChildScrollView(
              child: Column(
                children: [
                  SizedBox(
                    height: 168,
                  ),
                  Container(
                    child: SvgPicture.asset("assets/icons/otp_icon.svg"),
                  ),
                  Container(
                      margin: EdgeInsets.symmetric(horizontal: 24),
                      child: Text(
                        "OTP Verification",
                        style: Styles.p0(fontSize: 24),
                      )),
                  SizedBox(
                    height: 20,
                  ),
                  Container(
                    margin: EdgeInsets.symmetric(horizontal: 24),
                    child: RichText(
                      text: TextSpan(
                        text: 'Please enter ',
                        style: Styles.p3(),
                        children: <TextSpan>[
                          TextSpan(
                              text: '4 digit',
                              style: Styles.p3(
                                  fontWeight: FontWeight.bold,
                                  color: defaultColor ?? Color(0xff0000))),
                          TextSpan(
                              text: ' code we sent to your email.',
                              style: Styles.p3()),
                        ],
                      ),
                    ),
                  ),
                  SizedBox(
                    height: 57,
                  ),
                  Container(
                    margin: EdgeInsets.symmetric(horizontal: 25),
                    child: OTPTextField(
                      length: 4,
                      width: MediaQuery.of(context).size.width,
                      fieldWidth: 50,
                      style: TextStyle(fontSize: 17),
                      textFieldAlignment: MainAxisAlignment.spaceEvenly,
                      fieldStyle: FieldStyle.box,
                      onCompleted: (pin) {
                        print("Completed: " + pin);
                      },
                      onChanged: (pin) {
                        otpResetPasswordVerifyCtx.text = pin.toString();
                      },
                    ),
                  ),
                  SizedBox(
                    height: 32,
                  ),
                  Container(
                    margin: EdgeInsets.symmetric(horizontal: 24),
                    child: RichText(
                      text: TextSpan(
                        text: 'Didn’t receive the OTP? ',
                        style: Styles.p0(),
                        children: <TextSpan>[
                          TextSpan(
                              text: 'RESEND OTP',
                              style: Styles.p0(
                                  color: defaultColor ?? Color(0xff0000)),
                              recognizer: TapGestureRecognizer()
                                ..onTap = () {
                                  // authNot.sendEmailOtp(context, ref);
                                }),
                        ],
                      ),
                    ),
                  ),
                  SizedBox(
                    height: 32,
                  ),
                  Container(
                    height: 54,
                    margin: EdgeInsets.symmetric(horizontal: 24),
                    child: Row(
                      children: [
                        Expanded(
                          child: CustomButton(
                            text: "Confirm",
                            color: defaultColor ?? Color(0xff0000),
                            onPressed: () {
                              // authNot.verifyEmail(context, ref);
                              // Navigator.pushNamedAndRemoveUntil(context, ResetPasswordScreen.pageId, (route) => false);
                            },
                          ),
                        ),
                      ],
                    ),
                  ),
                  SizedBox(
                    height: 20,
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}

==> 0.1.0-dev.tar.gz: lib/src/screens/verifyemail.dart <==
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:loading_overlay/loading_overlay.dart';
import 'package:otp_text_field/otp_field.dart';
import 'package:otp_text_field/style.dart';
import 'package:storebounty_auth/src/widget/alert/alertclass.dart';
import 'package:storebounty_auth/src/widget/custombutton.dart';
import 'package:storebounty_auth/src/widget/styles/colors.dart';
import 'package:storebounty_auth/src/widget/styles/textstles.dart';
import 'package:storebounty_auth/storebounty_auth_v1.dart';
import 'package:storebounty_init/storebountyinit.dart';

class VerifyEmail extends StatefulWidget {
  static const pageId = "verify-email-otp-screen";
  final VoidCallback emailVerified;
  const VerifyEmail({super.key, required this.emailVerified});

  @override
  State<VerifyEmail> createState() => _VerifyEmailState();
}

class _VerifyEmailState extends State<VerifyEmail> {
  TextEditingController otpResetPasswordVerifyCtx = TextEditingController();

  Color? defaultColor;
  bool isVerifyingEmail = false;

  @override
  void initState() {
    getColor();
    // resetDiscountCode();
    super.initState();
  }

  getColor() async {
    var colorString = await StoreBountyInit.getStoreColor() ?? "#000000";
    defaultColor = Color(int.parse("0xff" + colorString.substring(1)));
    var currencySymbol = await StoreBountyInit.getCurrencySymbol();
    setState(() {});
  }

  verifyEmail()async{

    try{

      setState(() {
        isVerifyingEmail = true;
      });

      var body = {
        "otp": otpResetPasswordVerifyCtx.text.trim()
      };

      final response = await StorebountyAuth().verifyEmail(body);

     widget.emailVerified();

    }catch(e){
      AlertClass.error(context, "$e");
      setState(() {
        isVerifyingEmail = false;
      });

    }

  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () {
        FocusScope.of(context).unfocus();
      },
      child: LoadingOverlay(
        isLoading: isVerifyingEmail,
        color: defaultColor?.withOpacity(0.2) ?? Color(0xff0000).withOpacity(0.2),
        progressIndicator: CircularProgressIndicator(
          color: defaultColor,
        ),
        child: Scaffold(
          backgroundColor: AppColors.whiteColor,
          body: Container(
            child: SingleChildScrollView(
              child: Column(
                children: [
                  SizedBox(
                    height: 168,
                  ),
                  Container(
                    child: SvgPicture.asset("assets/icons/otp_icon.svg"),
                  ),
                  Container(
                      margin: EdgeInsets.symmetric(horizontal: 24),
                      child: Text(
                        "OTP Verification",
                        style: Styles.p0(fontSize: 24),
                      )),
                  SizedBox(
                    height: 20,
                  ),
                  Container(
                    margin: EdgeInsets.symmetric(horizontal: 24),
                    child: RichText(
                      text: TextSpan(
                        text: 'Please enter ',
                        style: Styles.p3(),
                        children: <TextSpan>[
                          TextSpan(
                              text: '4 digit',
                              style: Styles.p3(
                                  fontWeight: FontWeight.bold,
                                  color: defaultColor ?? Color(0xff0000))),
                          TextSpan(
                              text: ' code we sent to your email.',
                              style: Styles.p3()),
                        ],
                      ),
                    ),
                  ),
                  SizedBox(
                    height: 57,
                  ),
                  Container(
                    margin: EdgeInsets.symmetric(horizontal: 25),
                    child: OTPTextField(
                      length: 4,
                      width: MediaQuery.of(context).size.width,
                      fieldWidth: 50,
                      style: TextStyle(fontSize: 17),
                      textFieldAlignment: MainAxisAlignment.spaceEvenly,
                      fieldStyle: FieldStyle.box,
                      onCompleted: (pin) {
                        print("Completed: " + pin);
                      },
                      onChanged: (pin) {
                        otpResetPasswordVerifyCtx.text = pin.toString();
                      },
                    ),
                  ),
                  SizedBox(
                    height: 32,
                  ),
                  Container(
                    margin: EdgeInsets.symmetric(horizontal: 24),
                    child: RichText(
                      text: TextSpan(
                        text: 'Didn’t receive the OTP? ',
                        style: Styles.p0(),
                        children: <TextSpan>[
                          TextSpan(
                              text: 'RESEND OTP',
                              style: Styles.p0(
                                  color: defaultColor ?? Color(0xff0000)),
                              recognizer: TapGestureRecognizer()
                                ..onTap = () {
                                  // authNot.sendEmailOtp(context, ref);
                                }),
                        ],
                      ),
                    ),
                  ),
                  SizedBox(
                    height: 32,
                  ),
                  Container(
                    height: 54,
                    margin: EdgeInsets.symmetric(horizontal: 24),
                    child: Row(
                      children: [
                        Expanded(
                          child: CustomButton(
                            text: "Confirm",
                            color: defaultColor ?? Color(0xff0000),
                            onPressed: () {
                              verifyEmail();
                            },
                          ),
                        ),
                      ],
                    ),
                  ),
                  SizedBox(
                    height: 20,
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}
